<?php
/*
** ZABBIX
** Copyright (C) 2000-2008 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	'S_DATE_FORMAT_YMDHMS'=>			'd M H:i:s',
	'S_DATE_FORMAT_YMD'=>			'Y M d',
	'S_HTML_CHARSET'=>			'UTF-8',
	'S_CREATE_RULE'=>			'Skapa regel',
	'S_ACKNOWLEDGES'=>			'Bekräftelser',
	'S_ACKNOWLEDGE'=>			'Bekräfta',
	'S_ACKNOWLEDGE_ALARM_BY'=>			'Bekräfta alarm för',
	'S_ADD_COMMENT_BY'=>			'Lägg till kommentar av',
	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ALARMBEKRÄFTELSER',
	'S_CONFIGURATION_OF_ACTIONS'=>			'Konfiguration av åtgärder',
	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'KONFIGURATION AV ÅTGÄRDER',
	'S_SEND_MESSAGE'=>			'Skicka meddelande',
	'S_REMOTE_COMMAND'=>			'Fjärrkommando',
	'S_FILTER'=>			'Filter',
	'S_TRIGGER_SEVERITY'=>			'Allvarlighetsgrad för utlösare',
	'S_TRIGGER_VALUE'=>			'Värde för utlösare',
	'S_TIME_PERIOD'=>			'Tidsperiod',
	'S_TRIGGER_DESCRIPTION'=>			'Beskrivning av utlösare',
	'S_CONDITIONS'=>			'Villkor',
	'S_CONDITION'=>			'Villkor',
	'S_NO_CONDITIONS_DEFINED'=>			'Inga villkor har definierats',
	'S_ACTIONS_DELETED'=>			'Åtgärder borttagna',
	'S_CANNOT_DELETE_ACTIONS'=>			'Kan inte ta bort åtgärder',
	'S_ACTIONS'=>			'Åtgärder',
	'S_ACTIONS_BIG'=>			'ÅTGÄRDER',
	'S_ACTION_ADDED'=>			'Åtgärd lades till',
	'S_CANNOT_ADD_ACTION'=>			'Kan inte lägga till åtgärd',
	'S_ACTION_UPDATED'=>			'Åtgärd uppdaterad',
	'S_CANNOT_UPDATE_ACTION'=>			'Kan inte uppdatera åtgärd',
	'S_ACTION_DELETED'=>			'Åtgärd borttagen',
	'S_CANNOT_DELETE_ACTION'=>			'Kan inte ta bort åtgärd',
	'S_SEND_MESSAGE_TO'=>			'Skicka meddelande till',
	'S_DELAY'=>			'Fördröjning',
	'S_SUBJECT'=>			'Ämne',
	'S_ON'=>			'P',
	'S_OFF'=>			'AV',
	'S_NO_ACTIONS_DEFINED'=>			'Inga åtgärder har definierats',
	'S_SINGLE_USER'=>			'En användare',
	'S_USER_GROUP'=>			'Användargrupp',
	'S_GROUP'=>			'Grupp',
	'S_USER'=>			'Användare',
	'S_MESSAGE'=>			'Meddelande',
	'S_NOT_CLASSIFIED'=>			'Inte klassifierad',
	'S_INFORMATION'=>			'Information',
	'S_WARNING'=>			'Varning',
	'S_AVERAGE'=>			'Medel',
	'S_HIGH'=>			'Hög',
	'S_DISASTER'=>			'Allvarlig',
	'S_CREATE_ACTION'=>			'Skapa åtgärd',
	'S_SHOW_ALL'=>			'Visa alla',
	'S_TIME'=>			'Tid',
	'S_STATUS'=>			'Status',
	'S_DURATION'=>			'Längd',
	'S_TRUE_BIG'=>			'SANT',
	'S_FALSE_BIG'=>			'FALSKT',
	'S_UNKNOWN_BIG'=>			'OKÄNT',
	'S_TYPE'=>			'Typ',
	'S_RECIPIENTS'=>			'Mottagare',
	'S_ERROR'=>			'Fel',
	'S_SENT'=>			'skickat',
	'S_NOT_SENT'=>			'inte skickat',
	'S_NO_ACTIONS_FOUND'=>			'Inga åtgärder hittades',
	'S_CUSTOM_GRAPHS'=>			'Anpassade diagram',
	'S_GRAPHS_BIG'=>			'DIAGRAM',
	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Välj diagram att visa',
	'S_PERIOD'=>			'Period',
	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Välj diagram...',
	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'Kan inte uppdatera värdeskarta',
	'S_VALUE_MAP_ADDED'=>			'Värdeskarta lades till',
	'S_CANNNOT_ADD_VALUE_MAP'=>			'Kan inte lägga till värdeskarta',
	'S_VALUE_MAP_DELETED'=>			'Värdeskarta borttagen',
	'S_CANNNOT_DELETE_VALUE_MAP'=>			'Kan inte ta bort värdeskarta',
	'S_VALUE_MAP_UPDATED'=>			'Värdeskarta uppdaterad',
	'S_VALUE_MAPPING_BIG'=>			'VÄRDESMAPPNING',
	'S_VALUE_MAPPING'=>			'Värdesmappning',
	'S_VALUE_MAP'=>			'Värdeskarta',
	'S_MAPPING'=>			'Mappning',
	'S_NEW_MAPPING'=>			'Ny mappning',
	'S_NO_MAPPING_DEFINED'=>			'Ingen mappning definierad',
	'S_CREATE_VALUE_MAP'=>			'Skapa värdeskarta',
	'S_CONFIGURATION_OF_ZABBIX'=>			'Konfiguration av ZABBIX',
	'S_CONFIGURATION_OF_ZABBIX_BIG'=>			'KONFIGURATION AV ZABBIX',
	'S_CONFIGURATION_UPDATED'=>			'Konfiguration uppdaterad',
	'S_CONFIGURATION_WAS_NOT_UPDATED'=>			'Konfiguration blev inte uppdaterad',
	'S_ADDED_NEW_MEDIA_TYPE'=>			'Lade till ny mediatyp',
	'S_NEW_MEDIA_TYPE_WAS_NOT_ADDED'=>			'Ny mediatyp lades inte till',
	'S_MEDIA_TYPE_UPDATED'=>			'Mediatyp uppdaterad',
	'S_MEDIA_TYPE_WAS_NOT_UPDATED'=>			'Mediatyp blev inte uppdaterad',
	'S_MEDIA_TYPE_DELETED'=>			'Mediatyp borttagen',
	'S_MEDIA_TYPE_WAS_NOT_DELETED'=>			'Mediatyp blev inte borttagen',
	'S_CONFIGURATION'=>			'Konfiguration',
	'S_DO_NOT_KEEP_ACTIONS_OLDER_THAN'=>			'Behåll inte åtgärder äldre än (i dagar)',
	'S_DO_NOT_KEEP_EVENTS_OLDER_THAN'=>			'Behåll inte händelser äldre än (i dagar)',
	'S_NO_MEDIA_TYPES_DEFINED'=>			'Inga mediatyper har definierats',
	'S_SMTP_SERVER'=>			'SMTP-server',
	'S_SMTP_HELO'=>			'SMTP helo',
	'S_SMTP_EMAIL'=>			'SMTP email',
	'S_SCRIPT_NAME'=>			'Skriptnamn',
	'S_DELETE_SELECTED_MEDIA'=>			'Ta bort markerat media?',
	'S_DELETE_SELECTED_IMAGE'=>			'Ta bort markerad bild?',
	'S_HOUSEKEEPER'=>			'Hushållerska',
	'S_MEDIA_TYPES'=>			'Mediatyper',
	'S_ESCALATION_RULES'=>			'Eskaleringsregler',
	'S_ESCALATION'=>			'Eskalering',
	'S_ESCALATION_RULE'=>			'Eskaleringsregel',
	'S_DEFAULT'=>			'Standard',
	'S_IMAGES'=>			'Bilder',
	'S_IMAGE'=>			'Bild',
	'S_IMAGES_BIG'=>			'BILDER',
	'S_ICON'=>			'Ikon',
	'S_NO_IMAGES_DEFINED'=>			'Inga bilder har definierats',
	'S_BACKGROUND'=>			'Bakgrund',
	'S_UPLOAD'=>			'Skicka upp',
	'S_IMAGE_ADDED'=>			'Bild lades till',
	'S_CANNOT_ADD_IMAGE'=>			'Kan inte lägga till bild',
	'S_IMAGE_DELETED'=>			'Bild togs bort',
	'S_CANNOT_DELETE_IMAGE'=>			'Kan inte ta bort bild',
	'S_IMAGE_UPDATED'=>			'Bild uppdaterades',
	'S_CANNOT_UPDATE_IMAGE'=>			'Kan inte uppdatera bild',
	'S_OTHER'=>			'Övrigt',
	'S_OTHER_PARAMETERS'=>			'Övriga parametrar',
	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Uppdatera objekt som inte stöds (i sekunder)',
	'S_CREATE_MEDIA_TYPE'=>			'Skapa mediatyp',
	'S_CREATE_IMAGE'=>			'Skapa bild',
	'S_WORKING_TIME'=>			'Arbetstid',
	'S_NO_PERMISSIONS'=>			'Inga rättigheter!',
	'S_LATEST_DATA_BIG'=>			'SENASTE DATA',
	'S_ALL_SMALL'=>			'alla',
	'S_MINUS_ALL_MINUS'=>			'- alla -',
	'S_MINUS_OTHER_MINUS'=>			'- övriga -',
	'S_GRAPH'=>			'Diagram',
	'S_CONNECTED_AS'=>			'Ansluten som',
	'S_ITEM_ADDED'=>			'Objekt lades till',
	'S_ITEM_UPDATED'=>			'Objekt uppdaterades',
	'S_PARAMETER'=>			'Parameter',
	'S_COLOR'=>			'Färg',
	'S_UP'=>			'Uppåt',
	'S_DOWN'=>			'Nedåt',
	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Nytt objekt för diagrammet',
	'S_SORT_ORDER_0_100'=>			'Sorteringsordning (0->100)',
	'S_YAXIS_SIDE'=>			'Y-axel',
	'S_LEFT'=>			'Vänster',
	'S_FUNCTION'=>			'Funktion',
	'S_MIN_SMALL'=>			'min',
	'S_AVG_SMALL'=>			'medel',
	'S_MAX_SMALL'=>			'max',
	'S_DRAW_STYLE'=>			'Ritstil',
	'S_SIMPLE'=>			'Enkel',
	'S_AGGREGATED'=>			'Samlad',
	'S_AGGREGATED_PERIODS_COUNT'=>			'Antal perioder',
	'S_CONFIGURATION_OF_GRAPHS'=>			'Konfiguration av diagram',
	'S_CONFIGURATION_OF_GRAPHS_BIG'=>			'KONFIGURATION AV DIAGRAM',
	'S_GRAPH_ADDED'=>			'Diagram lades till',
	'S_GRAPH_UPDATED'=>			'Diagram uppdaterades',
	'S_CANNOT_UPDATE_GRAPH'=>			'Kan inte uppdatera diagram',
	'S_GRAPH_DELETED'=>			'Diagram togs bort',
	'S_CANNOT_DELETE_GRAPH'=>			'Kan inte ta bort diagram',
	'S_CANNOT_ADD_GRAPH'=>			'Kan inte lägga till diagram',
	'S_ID'=>			'Id',
	'S_NO_GRAPHS_DEFINED'=>			'Inga diagram har definierats',
	'S_DELETE_GRAPH_Q'=>			'Ta bort diagram?',
	'S_YAXIS_MIN_VALUE'=>			'MIN-värde för Y-axel',
	'S_YAXIS_MAX_VALUE'=>			'MAX-värde för Y-axel',
	'S_CALCULATED'=>			'Beräknade',
	'S_FIXED'=>			'Fast',
	'S_CREATE_GRAPH'=>			'Skapa diagram',
	'S_SHOW_WORKING_TIME'=>			'Visa arbetstid',
	'S_SHOW_TRIGGERS'=>			'Visa utlösare',
	'S_LAST_HOUR_GRAPH'=>			'Diagram för senaste timmen',
	'S_500_LATEST_VALUES'=>			'500 senaste värdena',
	'S_TIMESTAMP'=>			'Tidsstämpel',
	'S_LOCAL'=>			'Lokal',
	'S_SOURCE'=>			'Källa',
	'S_SHOW_SELECTED'=>			'Visa markerade',
	'S_HIDE_SELECTED'=>			'Dölj markerade',
	'S_MARK_SELECTED'=>			'Markera markerade',
	'S_MARK_OTHERS'=>			'Markera övriga',
	'S_AS_RED'=>			'som Röd',
	'S_AS_GREEN'=>			'som Grön',
	'S_AS_BLUE'=>			'som Bl',
	'S_APPLICATION'=>			'Program',
	'S_APPLICATIONS'=>			'Program',
	'S_APPLICATIONS_BIG'=>			'PROGRAM',
	'S_CREATE_APPLICATION'=>			'Skapa program',
	'S_APPLICATION_UPDATED'=>			'Program uppdaterat',
	'S_CANNOT_UPDATE_APPLICATION'=>			'Kan inte uppdatera program',
	'S_APPLICATION_ADDED'=>			'Program lades till',
	'S_CANNOT_ADD_APPLICATION'=>			'Kan inte lägga till program',
	'S_APPLICATION_DELETED'=>			'Program togs bort',
	'S_CANNOT_DELETE_APPLICATION'=>			'Kan inte ta bort program',
	'S_HOSTS'=>			'Värdar',
	'S_ITEMS'=>			'Objekt',
	'S_ITEMS_BIG'=>			'OBJEKT',
	'S_TRIGGERS'=>			'Utlösare',
	'S_GRAPHS'=>			'Diagram',
	'S_HOST_ADDED'=>			'Värd lades till',
	'S_CANNOT_ADD_HOST'=>			'Kan inte lägga till värd',
	'S_HOST_UPDATED'=>			'Värd uppdaterades',
	'S_CANNOT_UPDATE_HOST'=>			'Kan inte uppdatera värd',
	'S_HOST_STATUS_UPDATED'=>			'Värdstatus uppdaterades',
	'S_CANNOT_UPDATE_HOST_STATUS'=>			'Kan inte uppdatera värdstatus',
	'S_HOST_DELETED'=>			'Värd togs bort',
	'S_CANNOT_DELETE_HOST'=>			'Kan inte ta bort värd',
	'S_HOST_GROUPS_BIG'=>			'VÄRDGRUPPER',
	'S_NO_HOST_GROUPS_DEFINED'=>			'Inga värdgrupper har definierats',
	'S_NO_HOSTS_DEFINED'=>			'Inga värdar har definierats',
	'S_HOSTS_BIG'=>			'VÄRDAR',
	'S_HOST'=>			'Värd',
	'S_IP'=>			'IP',
	'S_PORT'=>			'Port',
	'S_MONITORED'=>			'Övervakad',
	'S_NOT_MONITORED'=>			'Inte övervakad',
	'S_TEMPLATE'=>			'Mall',
	'S_DELETED'=>			'Borttagen',
	'S_UNKNOWN'=>			'Okänd',
	'S_GROUPS'=>			'Grupper',
	'S_NEW_GROUP'=>			'Ny grupp',
	'S_IP_ADDRESS'=>			'IP-adress',
	'S_LINK_WITH_TEMPLATE'=>			'Koppla mot mall',
	'S_USE_PROFILE'=>			'Använd profil',
	'S_DELETE_SELECTED_HOST_Q'=>			'Ta bort markerad värd?',
	'S_GROUP_NAME'=>			'Gruppnamn',
	'S_HOST_GROUP'=>			'Värdgrupp',
	'S_HOST_GROUPS'=>			'Värdgrupper',
	'S_UPDATE'=>			'Uppdatera',
	'S_AVAILABILITY'=>			'Tillgänglighet',
	'S_AVAILABLE'=>			'Tillgänglig',
	'S_NOT_AVAILABLE'=>			'Inte tillgänglig',
	'S_HOST_PROFILE'=>			'Värdprofil',
	'S_DEVICE_TYPE'=>			'Enhetstyp',
	'S_OS'=>			'OS',
	'S_SERIALNO'=>			'Serienummer',
	'S_TAG'=>			'Tagg',
	'S_HARDWARE'=>			'Hårdvara',
	'S_SOFTWARE'=>			'Programvara',
	'S_CONTACT'=>			'Kontakt',
	'S_LOCATION'=>			'Plats',
	'S_NOTES'=>			'Anteckningar',
	'S_MACADDRESS'=>			'MAC-adress',
	'S_ADD_TO_GROUP'=>			'Lägg till i grupp',
	'S_DELETE_FROM_GROUP'=>			'Ta bort från grupp',
	'S_UPDATE_IN_GROUP'=>			'Uppdatera i grupp',
	'S_DELETE_SELECTED_HOSTS_Q'=>			'Ta bort markerade värdar?',
	'S_CREATE_HOST'=>			'Skapa värd',
	'S_CREATE_TEMPLATE'=>			'Skapa mall',
	'S_TEMPLATE_LINKAGE'=>			'Mallkoppling',
	'S_TEMPLATES'=>			'Mallar',
	'S_TEMPLATES_BIG'=>			'MALLAR',
	'S_NO_ITEMS_DEFINED'=>			'Inga objekt har definierats',
	'S_HISTORY_CLEARED'=>			'Historik rensad',
	'S_CANNOT_CLEAR_HISTORY'=>			'Kan inte rensa historik',
	'S_CONFIGURATION_OF_ITEMS'=>			'Konfiguration av objekt',
	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'KONFIGURATION AV OBJEKT',
	'S_CANNOT_UPDATE_ITEM'=>			'Kan inte uppdatera objekt',
	'S_STATUS_UPDATED'=>			'Status uppdaterad',
	'S_CANNOT_UPDATE_STATUS'=>			'Kan inte uppdatera status',
	'S_CANNOT_ADD_ITEM'=>			'Kan inte lägga till objekt',
	'S_ITEM_DELETED'=>			'Objekt togs bort',
	'S_CANNOT_DELETE_ITEM'=>			'Kan inte ta bort objekt',
	'S_ITEMS_DELETED'=>			'Objekt borttagna',
	'S_CANNOT_DELETE_ITEMS'=>			'Kan inte ta bort objekt',
	'S_ITEMS_ACTIVATED'=>			'Objekt aktiverade',
	'S_ITEMS_DISABLED'=>			'Objekt inaktiverade',
	'S_KEY'=>			'Nyckel',
	'S_DESCRIPTION'=>			'Beskrivning',
	'S_UPDATE_INTERVAL'=>			'Uppdateringsintervall',
	'S_HISTORY'=>			'Historik',
	'S_TRENDS'=>			'Trender',
	'S_ZABBIX_AGENT'=>			'ZABBIX-agent',
	'S_ZABBIX_AGENT_ACTIVE'=>			'ZABBIX-agent (aktiv)',
	'S_SNMPV1_AGENT'=>			'SNMPv1-agent',
	'S_ZABBIX_TRAPPER'=>			'ZABBIX-fångare',
	'S_SIMPLE_CHECK'=>			'Enkel kontroll',
	'S_SNMPV2_AGENT'=>			'SNMPv2-agent',
	'S_SNMPV3_AGENT'=>			'SNMPv3-agent',
	'S_ZABBIX_INTERNAL'=>			'ZABBIX internt',
	'S_ZABBIX_AGGREGATE'=>			'ZABBIX samlat',
	'S_ACTIVE'=>			'Aktiv',
	'S_NOT_SUPPORTED'=>			'Stöds inte',
	'S_EMAIL'=>			'E-post',
	'S_SMS'=>			'SMS',
	'S_SCRIPT'=>			'Skript',
	'S_GSM_MODEM'=>			'GSM-modem',
	'S_UNITS'=>			'Enheter',
	'S_UPDATE_INTERVAL_IN_SEC'=>			'Uppdateringsintervall (i sekunder)',
	'S_KEEP_HISTORY_IN_DAYS'=>			'Behåll historik (i dagar)',
	'S_KEEP_TRENDS_IN_DAYS'=>			'Behåll trender (i dagar)',
	'S_TYPE_OF_INFORMATION'=>			'Typ av information',
	'S_STORE_VALUE'=>			'Lagra värde',
	'S_SHOW_VALUE'=>			'Visa värde',
	'S_NUMERIC_UNSIGNED'=>			'Numerisk (heltal 64-bit)',
	'S_NUMERIC_FLOAT'=>			'Numerisk (flyttal)',
	'S_CHARACTER'=>			'Tecken',
	'S_LOG'=>			'Logg',
	'S_TEXT'=>			'Text',
	'S_AS_IS'=>			'Som det är',
	'S_DELTA_SPEED_PER_SECOND'=>			'Delta (hastighet per sekund)',
	'S_DELTA_SIMPLE_CHANGE'=>			'Delta (enkel ändring)',
	'S_ITEM'=>			'Objekt',
	'S_SNMP_COMMUNITY'=>			'SNMP community',
	'S_SNMP_OID'=>			'SNMP OID',
	'S_SNMP_PORT'=>			'SNMP-port',
	'S_ALLOWED_HOSTS'=>			'Tillåtna värdar',
	'S_SNMPV3_SECURITY_NAME'=>			'SNMPv3 security name',
	'S_SNMPV3_SECURITY_LEVEL'=>			'SNMPv3 security level',
	'S_SNMPV3_AUTH_PASSPHRASE'=>			'SNMPv3 auth passphrase',
	'S_SNMPV3_PRIV_PASSPHRASE'=>			'SNMPv3 priv passphrase',
	'S_CUSTOM_MULTIPLIER'=>			'Anpassad faktor',
	'S_DO_NOT_USE'=>			'Använd inte',
	'S_USE_MULTIPLIER'=>			'Använd faktor',
	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Välj värd...',
	'S_LOG_TIME_FORMAT'=>			'Tidsformat för logg',
	'S_CREATE_ITEM'=>			'Skapa objekt',
	'S_LATEST_EVENTS'=>			'Senaste händelser',
	'S_HISTORY_OF_EVENTS_BIG'=>			'HÄNDELSEHISTORIK',
	'S_NO_EVENTS_FOUND'=>			'Inga händelser hittades',
	'S_LAST_CHECK'=>			'Senaste kontroll',
	'S_LAST_VALUE'=>			'Senaste värde',
	'S_LINK'=>			'Länk',
	'S_LABEL'=>			'Etikett',
	'S_X'=>			'X',
	'S_Y'=>			'Y',
	'S_LINK_STATUS_INDICATOR'=>			'Länkstatusindikator',
	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'KONFIGURATION AV NÄTVERKSKARTOR',
	'S_MAPS_BIG'=>			'KARTOR',
	'S_NO_MAPS_DEFINED'=>			'Inga kartor har definierats',
	'S_CREATE_MAP'=>			'Skapa karta',
	'S_ICON_LABEL_LOCATION'=>			'Position för ikonetikett',
	'S_BOTTOM'=>			'Nederkant',
	'S_TOP'=>			'Överkant',
	'S_OK_BIG'=>			'OK',
	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
	'S_NETWORK_MAPS'=>			'Nätverkskartor',
	'S_NETWORK_MAPS_BIG'=>			'NÄTVERKSKARTOR',
	'S_BACKGROUND_IMAGE'=>			'Bakgrundsbild',
	'S_ICON_LABEL_TYPE'=>			'Typ av ikonetikett',
	'S_LABEL_LOCATION'=>			'Etikettposition',
	'S_ELEMENT_NAME'=>			'Elementnamn',
	'S_STATUS_ONLY'=>			'Endast status',
	'S_NOTHING'=>			'Ingenting',
	'S_MEDIA'=>			'Media',
	'S_SEND_TO'=>			'Skicka till',
	'S_WHEN_ACTIVE'=>			'När aktiv',
	'S_NO_MEDIA_DEFINED'=>			'Inget media har definierats',
	'S_NEW_MEDIA'=>			'Nytt media',
	'S_USE_IF_SEVERITY'=>			'Använd om allvarlighetsgrad',
	'S_SAVE'=>			'Spara',
	'S_CANCEL'=>			'Avbryt',
	'S_OVERVIEW'=>			'Översikt',
	'S_OVERVIEW_BIG'=>			'ÖVERSIKT',
	'S_DATA'=>			'Data',
	'S_QUEUE_BIG'=>			'K',
	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>			'UPPDATERINGSKÖ FÖR OBJEKT',
	'S_NEXT_CHECK'=>			'Nästa kontroll',
	'S_THE_QUEUE_IS_EMPTY'=>			'Kön är tom',
	'S_TOTAL'=>			'Totalt',
	'S_COUNT'=>			'Antal',
	'S_5_SECONDS'=>			'5 sekunder',
	'S_10_SECONDS'=>			'10 sekunder',
	'S_30_SECONDS'=>			'30 sekunder',
	'S_1_MINUTE'=>			'1 minut',
	'S_5_MINUTES'=>			'5 minuter',
	'S_STATUS_OF_ZABBIX'=>			'Status för ZABBIX',
	'S_STATUS_OF_ZABBIX_BIG'=>			'STATUS FÖR ZABBIX',
	'S_VALUE'=>			'Värde',
	'S_ZABBIX_SERVER_IS_RUNNING'=>			'ZABBIX-server kör',
	'S_VALUES_STORED'=>			'Lagrade värden',
	'S_TRENDS_STORED'=>			'Lagrade trender',
	'S_NUMBER_OF_ALERTS'=>			'Antal larm',
	'S_NUMBER_OF_TRIGGERS'=>			'Antal utlösare (aktiverade/inaktiverade)[sant/okänt/falskt]',
	'S_NUMBER_OF_TRIGGERS_SHORT'=>			'Utlösare (a/i)[s/o/f]',
	'S_NUMBER_OF_ITEMS'=>			'Antal objekt (övervakade/inaktiverade/stöds inte)[fångare]',
	'S_NUMBER_OF_ITEMS_SHORT'=>			'Objekt (ö/i/s)[f]',
	'S_NUMBER_OF_USERS'=>			'Antal användare (anslutna)',
	'S_NUMBER_OF_USERS_SHORT'=>			'Användare (anslutna)',
	'S_NUMBER_OF_HOSTS'=>			'Antal värdar (övervakade/inte övervakade/mallar/borttagna)',
	'S_NUMBER_OF_HOSTS_SHORT'=>			'Värdar (ö/i/m/b)',
	'S_YES'=>			'Ja',
	'S_NO'=>			'Nej',
	'S_RUNNING'=>			'kör',
	'S_NOT_RUNNING'=>			'kör inte',
	'S_AVAILABILITY_REPORT'=>			'Tillgänglighetsrapport',
	'S_AVAILABILITY_REPORT_BIG'=>			'TILLGÄNGLIGHETSRAPPORT',
	'S_SHOW'=>			'Visa',
	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Tillgänglighetsrapport för IT-tjänster',
	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'TILLGÄNGLIGHETSRAPPOR FÖR IT-TJÄNSTER',
	'S_FROM'=>			'Från',
	'S_TILL'=>			'Till',
	'S_OK'=>			'Ok',
	'S_PROBLEMS'=>			'Problem',
	'S_PERCENTAGE'=>			'Procentandel',
	'S_SLA'=>			'SLA',
	'S_DAY'=>			'Dag',
	'S_MONTH'=>			'Månad',
	'S_YEAR'=>			'År',
	'S_DAILY'=>			'Dagligen',
	'S_WEEKLY'=>			'Veckovis',
	'S_MONTHLY'=>			'Månatligen',
	'S_YEARLY'=>			'Årligen',
	'S_NOTIFICATIONS'=>			'Notifieringar',
	'S_NOTIFICATIONS_BIG'=>			'NOTIFIERINGAR',
	'S_IT_NOTIFICATIONS'=>			'Notifieringsrapport',
	'S_TRIGGERS_TOP_100'=>			'Mest använda utlösare - topp 100',
	'S_TRIGGERS_TOP_100_BIG'=>			'MEST ANVÄNDA UTLÖSARE - TOPP 100',
	'S_NUMBER_OF_STATUS_CHANGES'=>			'Antal statusändringar',
	'S_WEEK'=>			'Vecka',
	'S_LAST'=>			'Senaste',
	'S_SCREENS'=>			'Skärmar',
	'S_SCREEN'=>			'Skärm',
	'S_CONFIGURATION_OF_SCREENS_BIG'=>			'KONFIGURATION AV SKÄRMAR',
	'S_CONFIGURATION_OF_SCREENS'=>			'Konfiguration av skärmar',
	'S_SCREEN_ADDED'=>			'Skärm lades till',
	'S_CANNOT_ADD_SCREEN'=>			'Kan inte lägga till skärm',
	'S_SCREEN_UPDATED'=>			'Skärm uppdaterades',
	'S_CANNOT_UPDATE_SCREEN'=>			'Kan inte uppdatera skärm',
	'S_SCREEN_DELETED'=>			'Skärm togs bort',
	'S_CANNOT_DELETE_SCREEN'=>			'Kan inte ta bort skärm',
	'S_COLUMNS'=>			'Kolumner',
	'S_ROWS'=>			'Rader',
	'S_NO_SCREENS_DEFINED'=>			'Inga skärmar har definierats',
	'S_DELETE_SCREEN_Q'=>			'Ta bort skärm?',
	'S_CONFIGURATION_OF_SCREEN_BIG'=>			'KONFIGURATION AV SKÄRM',
	'S_SCREEN_CELL_CONFIGURATION'=>			'Konfiguration av skärmcell',
	'S_RESOURCE'=>			'Resurs',
	'S_SIMPLE_GRAPH'=>			'Enkelt diagram',
	'S_GRAPH_NAME'=>			'Diagramnamn',
	'S_WIDTH'=>			'Bredd',
	'S_HEIGHT'=>			'Höjd',
	'S_CREATE_SCREEN'=>			'Skapa skärm',
	'S_EDIT'=>			'Redigera',
	'S_DIMENSION_COLS_ROWS'=>			'Dimension (kolumner x rader)',
	'S_MAP'=>			'Karta',
	'S_AS_PLAIN_TEXT'=>			'Som ren text',
	'S_PLAIN_TEXT'=>			'Ren text',
	'S_COLUMN_SPAN'=>			'Kolumnspann',
	'S_ROW_SPAN'=>			'Radspann',
	'S_SHOW_LINES'=>			'Visa linjer',
	'S_HOSTS_INFO'=>			'Info om värdar',
	'S_TRIGGERS_INFO'=>			'Info om utlösare',
	'S_SERVER_INFO'=>			'Serverinfo',
	'S_CLOCK'=>			'Klocka',
	'S_TRIGGERS_OVERVIEW'=>			'Översikt över utlösare',
	'S_DATA_OVERVIEW'=>			'Översikt över data',
	'S_HISTORY_OF_ACTIONS'=>			'Historik för åtgärder',
	'S_HISTORY_OF_EVENTS'=>			'Historik för händelser',
	'S_TIME_TYPE'=>			'Tidstyp',
	'S_SERVER_TIME'=>			'Servertid',
	'S_LOCAL_TIME'=>			'Lokal tid',
	'S_STYLE'=>			'Stil',
	'S_VERTICAL'=>			'Vertikal',
	'S_HORIZONTAL'=>			'Horisontell',
	'S_HORIZONTAL_ALIGN'=>			'Horisontell justering',
	'S_CENTRE'=>			'Centrera',
	'S_RIGHT'=>			'Rättighet',
	'S_VERTICAL_ALIGN'=>			'Vertikal justering',
	'S_MIDDLE'=>			'Mitten',
	'S_CUSTOM_SCREENS'=>			'Anpassade skärmar',
	'S_SCREENS_BIG'=>			'SKÄRMAR',
	'S_IT_SERVICES'=>			'IT-tjänster',
	'S_SERVICE_UPDATED'=>			'Tjänst uppdaterad',
	'S_CANNOT_UPDATE_SERVICE'=>			'Kan inte uppdatera tjänst',
	'S_SERVICE_ADDED'=>			'Tjänst lades till',
	'S_CANNOT_ADD_SERVICE'=>			'Kan inte lägga till tjänst',
	'S_SERVICE_DELETED'=>			'Tjänst togs bort',
	'S_CANNOT_DELETE_SERVICE'=>			'Kan inte ta bort tjänst',
	'S_STATUS_CALCULATION'=>			'Statusberäkning',
	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algoritm för statusberäkning',
	'S_NONE'=>			'Ingen',
	'S_SOFT'=>			'Mjuk',
	'S_DO_NOT_CALCULATE'=>			'Beräkna inte',
	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'Acceptabel SLA (i %)',
	'S_LINK_TO_TRIGGER_Q'=>			'Länk till utlösare?',
	'S_SORT_ORDER_0_999'=>			'Sorteringsordning (0->999)',
	'S_TRIGGER'=>			'Utlösare',
	'S_SERVER'=>			'Server',
	'S_DELETE'=>			'Ta bort',
	'S_DEPENDS_ON'=>			'Beroende av',
	'S_IT_SERVICES_BIG'=>			'IT-TJÄNSTER',
	'S_SERVICE'=>			'Tjänst',
	'S_REASON'=>			'Anledning',
	'S_NO_TRIGGERS_DEFINED'=>			'Inga utlösare har definierats',
	'S_CONFIGURATION_OF_TRIGGERS'=>			'Konfiguration av utlösare',
	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'KONFIGURATION AV UTLÖSARE',
	'S_TRIGGERS_DELETED'=>			'Utlösare togs bort',
	'S_CANNOT_DELETE_TRIGGERS'=>			'Kan inte ta bort utlösare',
	'S_TRIGGER_DELETED'=>			'Utlösare togs bort',
	'S_CANNOT_DELETE_TRIGGER'=>			'Kan inte ta bort utlösare',
	'S_TRIGGER_ADDED'=>			'Utlösare lades till',
	'S_CANNOT_ADD_TRIGGER'=>			'Kan inte lägga till utlösare',
	'S_SEVERITY'=>			'Allvarlighetsgrad',
	'S_EXPRESSION'=>			'Uttryck',
	'S_DISABLED'=>			'Inaktiverad',
	'S_ENABLED'=>			'Aktiverad',
	'S_CHANGE'=>			'Ändra',
	'S_TRIGGER_UPDATED'=>			'Utlösare uppdaterades',
	'S_CANNOT_UPDATE_TRIGGER'=>			'Kan inte uppdatera utlösare',
	'S_URL'=>			'URL',
	'S_CREATE_TRIGGER'=>			'Skapa utlösare',
	'S_TRIGGER_COMMENTS'=>			'Kommentarer för utlösare',
	'S_TRIGGER_COMMENTS_BIG'=>			'KOMMENTARER FÖR UTLÖSARE',
	'S_COMMENT_UPDATED'=>			'Kommentar uppdaterades',
	'S_CANNOT_UPDATE_COMMENT'=>			'Kan inte uppdatera kommentar',
	'S_ADD'=>			'Lägg till',
	'S_STATUS_OF_TRIGGERS'=>			'Status för utlösare',
	'S_STATUS_OF_TRIGGERS_BIG'=>			'STATUS FÖR UTLÖSARE',
	'S_SHOW_DETAILS'=>			'Visa detaljer',
	'S_SELECT'=>			'Välj',
	'S_TRIGGERS_BIG'=>			'UTLÖSARE',
	'S_LAST_CHANGE'=>			'Senaste ändring',
	'S_COMMENTS'=>			'Kommentarer',
	'S_ACKNOWLEDGED'=>			'Bekräftade',
	'S_ACK'=>			'Bekräfta',
	'S_USERS'=>			'Användare',
	'S_USER_ADDED'=>			'Användare lades till',
	'S_CANNOT_ADD_USER'=>			'Kan inte lägga till användare',
	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'Kan inte lägga till användare. Båda lösenorden måste vara samma.',
	'S_USER_DELETED'=>			'Användare togs bort',
	'S_CANNOT_DELETE_USER'=>			'Kan inte ta bort användare',
	'S_USER_UPDATED'=>			'Användare uppdaterades',
	'S_CANNOT_UPDATE_USER'=>			'Kan inte uppdatera användare',
	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'Kan inte uppdatera användare. Båda lösenorden måste vara samma.',
	'S_GROUP_ADDED'=>			'Grupp lades till',
	'S_CANNOT_ADD_GROUP'=>			'Kan inte lägga till grupp',
	'S_GROUP_UPDATED'=>			'Grupp har uppdaterats',
	'S_CANNOT_UPDATE_GROUP'=>			'Kan inte uppdatera grupp',
	'S_GROUP_DELETED'=>			'Grupp togs bort',
	'S_CANNOT_DELETE_GROUP'=>			'Kan inte ta bort grupp',
	'S_CONFIGURATION_OF_USERS_AND_USER_GROUPS'=>			'KONFIGURATION AV ANVÄNDARE OCH ANVÄNDARGRUPPER',
	'S_USER_GROUPS_BIG'=>			'ANVÄNDARGRUPPER',
	'S_USERS_BIG'=>			'ANVÄNDARE',
	'S_USER_GROUPS'=>			'Användargrupper',
	'S_MEMBERS'=>			'Medlemmar',
	'S_NO_USER_GROUPS_DEFINED'=>			'Inga användargrupper har definierats',
	'S_ALIAS'=>			'Alias',
	'S_NAME'=>			'Namn',
	'S_SURNAME'=>			'Efternamn',
	'S_IS_ONLINE_Q'=>			'Är ansluten?',
	'S_NO_USERS_DEFINED'=>			'Inga användare har definierats',
	'S_READ_ONLY'=>			'Endast läs',
	'S_READ_WRITE'=>			'Läs-skriv',
	'S_HIDE'=>			'Dölj',
	'S_PASSWORD'=>			'Lösenord',
	'S_PASSWORD_ONCE_AGAIN'=>			'Lösenord (en gång till)',
	'S_URL_AFTER_LOGIN'=>			'URL (efter inloggning)',
	'S_SCREEN_REFRESH'=>			'Uppdatera (i sekunder)',
	'S_CREATE_USER'=>			'Skapa användare',
	'S_CREATE_GROUP'=>			'Skapa grupp',
	'S_ACTION'=>			'Åtgärd',
	'S_DETAILS'=>			'Detaljer',
	'S_UNKNOWN_ACTION'=>			'Okänd åtgärd',
	'S_ADDED'=>			'Lades till',
	'S_UPDATED'=>			'Uppdaterad',
	'S_MEDIA_TYPE'=>			'Mediatyp',
	'S_GRAPH_ELEMENT'=>			'Diagramelement',
	'S_UNKNOWN_RESOURCE'=>			'Okänd resurs',
	'S_USER_PROFILE_BIG'=>			'ANVÄNDARPROFIL',
	'S_USER_PROFILE'=>			'Användarprofil',
	'S_LANGUAGE'=>			'Språk',
	'S_ENGLISH_GB'=>			'Engelska (GB)',
	'S_FRENCH_FR'=>			'Franska (FR)',
	'S_GERMAN_DE'=>			'Tyska (DE)',
	'S_ITALIAN_IT'=>			'Italienska (IT)',
	'S_LATVIAN_LV'=>			'Lettiska (LV)',
	'S_RUSSIAN_RU'=>			'Ryska (RU)',
	'S_SPANISH_SP'=>			'Spanska (SP)',
	'S_JAPANESE_JP'=>			'Japanska (JP)',
	'S_CHINESE_CN'=>			'Kinesiska (CN)',
	'S_ZABBIX_BIG'=>			'ZABBIX',
	'S_HOST_PROFILES'=>			'Värdprofiler',
	'S_HOST_PROFILES_BIG'=>			'VÄRDPROFILER',
	'S_EMPTY'=>			'Tom',
	'S_STANDARD_ITEMS_BIG'=>			'STANDARDOBJEKT',
	'S_NO_ITEMS'=>			'Inga objekt',
	'S_HELP'=>			'Hjälp',
	'S_PROFILE'=>			'Profil',
	'S_MONITORING'=>			'Övervakning',
	'S_INVENTORY'=>			'Inventarier',
	'S_QUEUE'=>			'K',
	'S_EVENTS'=>			'Händelser',
	'S_MAPS'=>			'Kartor',
	'S_REPORTS'=>			'Rapporter',
	'S_GENERAL'=>			'Allmänt',
	'S_AUDIT'=>			'Granskning',
	'S_LOGIN'=>			'Inloggning',
	'S_LATEST_DATA'=>			'Senaste data',
	'S_INCORRECT_DESCRIPTION'=>			'Felaktig beskrivning',

	);
?>
